searchData={"items":[{"type":"module","title":"Couchx","doc":"Couchx context module","ref":"Couchx.html"},{"type":"module","title":"Couchx.Adapter","doc":"Adapter to get basic query functionality into `Ecto` with `CouchDB`.","ref":"Couchx.Adapter.html"},{"type":"module","title":"Configuration - Couchx.Adapter","doc":"It uses the same as Ecto pattern to config the Dbs with this format:\n\n```\nconfig :my_app, MyRepo,\n  username: \"username\",\n  password: \"password\",\n  database: \"db_name\",\n  hostname: \"localhost\",\n  protocol: \"http\",\n  port: 5984\n```","ref":"Couchx.Adapter.html#module-configuration"},{"type":"module","title":"Usage - Couchx.Adapter","doc":"Couchx supports 1 main repo and many dynamic supervised repos.\nA dynamic repo will allow you to have multiple db connections in your application.\nTo achieve this, you will need to setup a `Registry` in the application like:\n\n```\n  def start(_type, _args) do\n    children = [\n      {Registry, keys: :unique, name: CouchxRegistry},\n      ...\n    ]\n    ...\n  end\n```\n\nThe Restry name is tied up to the code so it must be called `CouchxRegistry`.\n\nThe main Repo is configured as any other Ecto Repo, so you can start it in the application just adding it to the children list.\n\n```\n  def start(_type, _args) do\n    children = [\n      MyDb.Repo\n    ]\n    ...\n  end\n```","ref":"Couchx.Adapter.html#module-usage"},{"type":"module","title":"Dynamic Repo queries - Couchx.Adapter","doc":"The dynamic repos are implemente with a Macro that you can get into your repo as:\n\n```\n  use CouchxDyncamicTepo, otp_app: :my_app, name: :my_repo\n```\n\nThis is used to setup a `run` function, with a callback as argument.\nTo execute actions in a dynamic repo we follow this pattern:\n\n```\n  MyDynamicRepo.run( ->\n    MyDynamicRepo.get(MyStruct, doc_id)\n  end)\n```\n\nAny Repo call inside the callback function will be run in a dynamically supervised connection.","ref":"Couchx.Adapter.html#module-dynamic-repo-queries"},{"type":"module","title":"Migrations - Couchx.Adapter","doc":"Couchx comes with a Mango index generator.","ref":"Couchx.Adapter.html#module-migrations"},{"type":"module","title":"Example - Couchx.Adapter","doc":"$ mix couchx.gen.mango_index -r MyApp.Repo -n my-mango-index -f username,email\n\nThis will create a file under `priv/my_app/repo/index/my-mango-index.exs` with contents as:\n\n````\ndefmodule MyApp.Repo.Index.MyMangoIndex do\n  use Couchx.MangoIndex, repo_name: MyApp.Repo\n\n  def up do\n    create_index \"my-mango-index\" do\n      %{\n         fields: [\"username\", \"email\"],\n       }\n    end\n  end\n\n  def down do\n    drop_index \"my-mango-index\"\n  end\nend\n\n````\n\nThe Map inside the `create_index` block will be added to the `index` json object, so any structure that can go there can be added here.\nCurrently only supported methods are","ref":"Couchx.Adapter.html#module-example"},{"type":"module","title":"create_index(String.t(), (-> Map.t())) - Couchx.Adapter","doc":"- name: ID and Name for the index to be created in CouchDB, this will be used as `id` for the document persisted.\n  - fun: A block that returns a formated Map for the index to be created, it will be parsed as JSON to the body of the index document.","ref":"Couchx.Adapter.html#module-create_index-string-t-map-t"},{"type":"module","title":"drop_index(String.t()) - Couchx.Adapter","doc":"- name: Id and Name for the index document to be deleted","ref":"Couchx.Adapter.html#module-drop_index-string-t"},{"type":"module","title":"Examples - Couchx.Adapter","doc":"$ mix couchx.mango_index\n\n    Will add all indexes store under `priv/my_app/repo/index/` paths\n\n    $ mix couchx.mango_index.down -r MyApp.Repo -n my-mango-index,my-other-index\n\n    It will call down function on the Migration files\n\n    ```\n      priv/my_app/repo/index/my-mango-index.exs\n      priv/my_app/repo/index/my-other-index.exs\n    ```\n\n    Removing the documents from the database.","ref":"Couchx.Adapter.html#module-examples"},{"type":"function","title":"Couchx.Adapter.create_admin/3","doc":"","ref":"Couchx.Adapter.html#create_admin/3"},{"type":"function","title":"Couchx.Adapter.create_db/2","doc":"","ref":"Couchx.Adapter.html#create_db/2"},{"type":"function","title":"Couchx.Adapter.delete/4","doc":"","ref":"Couchx.Adapter.html#delete/4"},{"type":"function","title":"Couchx.Adapter.delete_admin/2","doc":"","ref":"Couchx.Adapter.html#delete_admin/2"},{"type":"function","title":"Couchx.Adapter.delete_db/2","doc":"","ref":"Couchx.Adapter.html#delete_db/2"},{"type":"function","title":"Couchx.Adapter.do_insert/6","doc":"","ref":"Couchx.Adapter.html#do_insert/6"},{"type":"function","title":"Couchx.Adapter.execute/6","doc":"","ref":"Couchx.Adapter.html#execute/6"},{"type":"function","title":"Couchx.Adapter.parse_bulk_response/3","doc":"","ref":"Couchx.Adapter.html#parse_bulk_response/3"},{"type":"function","title":"Couchx.Adapter.update!/6","doc":"","ref":"Couchx.Adapter.html#update!/6"},{"type":"module","title":"Couchx.Constraint","doc":"","ref":"Couchx.Constraint.html"},{"type":"function","title":"Couchx.Constraint.call/4","doc":"","ref":"Couchx.Constraint.html#call/4"},{"type":"module","title":"Couchx.CouchId","doc":"","ref":"Couchx.CouchId.html"},{"type":"function","title":"Couchx.CouchId.base_id/1","doc":"","ref":"Couchx.CouchId.html#base_id/1"},{"type":"function","title":"Couchx.CouchId.underscore_school_id/1","doc":"","ref":"Couchx.CouchId.html#underscore_school_id/1"},{"type":"module","title":"Couchx.DbConnection","doc":"","ref":"Couchx.DbConnection.html"},{"type":"function","title":"Couchx.DbConnection.all_docs/3","doc":"","ref":"Couchx.DbConnection.html#all_docs/3"},{"type":"function","title":"Couchx.DbConnection.bulk_docs/3","doc":"","ref":"Couchx.DbConnection.html#bulk_docs/3"},{"type":"function","title":"Couchx.DbConnection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Couchx.DbConnection.html#child_spec/1"},{"type":"function","title":"Couchx.DbConnection.create_admin/3","doc":"","ref":"Couchx.DbConnection.html#create_admin/3"},{"type":"function","title":"Couchx.DbConnection.create_db/2","doc":"","ref":"Couchx.DbConnection.html#create_db/2"},{"type":"function","title":"Couchx.DbConnection.delete/3","doc":"","ref":"Couchx.DbConnection.html#delete/3"},{"type":"function","title":"Couchx.DbConnection.delete/4","doc":"","ref":"Couchx.DbConnection.html#delete/4"},{"type":"function","title":"Couchx.DbConnection.delete_admin/2","doc":"","ref":"Couchx.DbConnection.html#delete_admin/2"},{"type":"function","title":"Couchx.DbConnection.delete_db/2","doc":"","ref":"Couchx.DbConnection.html#delete_db/2"},{"type":"function","title":"Couchx.DbConnection.find/3","doc":"","ref":"Couchx.DbConnection.html#find/3"},{"type":"function","title":"Couchx.DbConnection.get/4","doc":"","ref":"Couchx.DbConnection.html#get/4"},{"type":"function","title":"Couchx.DbConnection.index/2","doc":"","ref":"Couchx.DbConnection.html#index/2"},{"type":"function","title":"Couchx.DbConnection.info/1","doc":"","ref":"Couchx.DbConnection.html#info/1"},{"type":"function","title":"Couchx.DbConnection.init/1","doc":"","ref":"Couchx.DbConnection.html#init/1"},{"type":"function","title":"Couchx.DbConnection.insert/4","doc":"","ref":"Couchx.DbConnection.html#insert/4"},{"type":"function","title":"Couchx.DbConnection.raw_request/4","doc":"","ref":"Couchx.DbConnection.html#raw_request/4"},{"type":"function","title":"Couchx.DbConnection.start_link/1","doc":"","ref":"Couchx.DbConnection.html#start_link/1"},{"type":"module","title":"Couchx.DocumentState","doc":"","ref":"Couchx.DocumentState.html"},{"type":"function","title":"Couchx.DocumentState.merge_constraints/1","doc":"","ref":"Couchx.DocumentState.html#merge_constraints/1"},{"type":"function","title":"Couchx.DocumentState.process_constraints/2","doc":"","ref":"Couchx.DocumentState.html#process_constraints/2"},{"type":"module","title":"Couchx.DynamicRepo","doc":"","ref":"Couchx.DynamicRepo.html"},{"type":"module","title":"Couchx.Finders","doc":"","ref":"Couchx.Finders.html"},{"type":"module","title":"Couchx.MangoIndex","doc":"","ref":"Couchx.MangoIndex.html"},{"type":"module","title":"Couchx.Migrator","doc":"","ref":"Couchx.Migrator.html"},{"type":"function","title":"Couchx.Migrator.run/2","doc":"","ref":"Couchx.Migrator.html#run/2"},{"type":"function","title":"Couchx.Migrator.run/3","doc":"","ref":"Couchx.Migrator.html#run/3"},{"type":"function","title":"Couchx.Migrator.run_direction/2","doc":"","ref":"Couchx.Migrator.html#run_direction/2"},{"type":"module","title":"Couchx.PrepareQuery","doc":"","ref":"Couchx.PrepareQuery.html"},{"type":"function","title":"Couchx.PrepareQuery.call/1","doc":"","ref":"Couchx.PrepareQuery.html#call/1"},{"type":"module","title":"Couchx.QueryHandler","doc":"","ref":"Couchx.QueryHandler.html"},{"type":"function","title":"Couchx.QueryHandler.query_results/3","doc":"","ref":"Couchx.QueryHandler.html#query_results/3"},{"type":"module","title":"Couchx.Support.ApplicationHelper","doc":"","ref":"Couchx.Support.ApplicationHelper.html"},{"type":"function","title":"Couchx.Support.ApplicationHelper.base_repo_path/2","doc":"","ref":"Couchx.Support.ApplicationHelper.html#base_repo_path/2"},{"type":"task","title":"mix couchx.gen.mango_index","doc":"","ref":"Mix.Tasks.Couchx.Gen.MangoIndex.html"},{"type":"task","title":"mix couchx.mango_index","doc":"Creates the index documents defined in the `priv/repo/index/` path.\n\nThe migration files should be `exs` files and can have a `up` and `down` functions.","ref":"Mix.Tasks.Couchx.MangoIndex.html"},{"type":"task","title":"Examples - mix couchx.mango_index","doc":"```\ndefmodule MyApp.Repo.Index.MyIndex do\n  use Couchx.MangoIndex, repo_name: BS.Repo\n\n  def up do\n    create_index(\"my-index\") do\n      %{fields: [\"name\", \"email\"]}\n    end\n  end\n\n  def down do\n    drop_index(\"my-index\")\n  end\nend\n```\n\nCurrent convention is that the file name uses `-` to separate words, and this is used to create de module name.","ref":"Mix.Tasks.Couchx.MangoIndex.html#module-examples"},{"type":"task","title":"Example - mix couchx.mango_index","doc":"$ priv/my_repo/index/my-index.exs\n    $ mix couchx.mango_index\n\nCouchx will need knowledge of the main OTP app supervising the repos, also we need to configure ecto repos.","ref":"Mix.Tasks.Couchx.MangoIndex.html#module-example"},{"type":"task","title":"Example - mix couchx.mango_index","doc":"```\n  confix :couchx, otp_app: :my_app\n  config :my_app, ecto_repos: [MyApp.Repo, Custom.Repo]\n```\n\nThe task will look for paths for all the repos and process the indexes it finds.","ref":"Mix.Tasks.Couchx.MangoIndex.html#module-example"},{"type":"task","title":"mix couchx.mango_index.down","doc":"Deletes an index or list of indexes provided from the Repo DB.\n\nThe Repo passed as `-r` or `--r` will define the DB to lookup for the index document.\nThere is also a parameter set as `-n` or `--names` which will need to match the `ddoc` and the index `name`.","ref":"Mix.Tasks.Couchx.MangoIndex.Down.html"},{"type":"task","title":"Examples - mix couchx.mango_index.down","doc":"$ mix couchx.mango_index.down -r MyApp.Repo -n my-index-ddoc\n\nThe Repo have to match one in the `config.exs` file. Also couchx will need knowledge of the main OTP app supervising the repos.","ref":"Mix.Tasks.Couchx.MangoIndex.Down.html#module-examples"},{"type":"task","title":"Examples - mix couchx.mango_index.down","doc":"```\n  confix :couchx, otp_app: :my_app\n  config :my_app, ecto_repos: [MyApp.Repo, Custom.Repo]\n```","ref":"Mix.Tasks.Couchx.MangoIndex.Down.html#module-examples"},{"type":"function","title":"Mix.Tasks.Couchx.MangoIndex.Down.prepend/2","doc":"","ref":"Mix.Tasks.Couchx.MangoIndex.Down.html#prepend/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}